@@ -1,8 +1,12 @@
 #! /usr/bin/env python3
+'''
+Usage: python3 /path/to/site-packages/pyscriptlib/example_script.py ~/some/example/dir arg2 arg3
+'''
+
 
 from pathlib import Path
 import time
-from pyscriptlib import arg, shift, env, sh, shx, shl, shk, sho, shb, kill, humanize
+from pyscriptlib import arg, nargs, shift, env, sh, shx, shl, shk, sho, shb, kill, humanize
 
 def title(descr, code):
     print(f'\n>>> {descr}\n>>> {code}')
@@ -13,6 +17,11 @@ title('Retrieve first sys.argv or os.environ variable MY_DIR_PATH or None if not
 dir_path = arg(1) or env('MY_DIR_PATH')
 print(f'{dir_path = }')
 
+title('Get remaining args',
+      'remaining_args = nargs(1)')
+remaining_args = nargs(2)
+print(f'{remaining_args = }')
+
 title('Shift args',
       'removed = shift()); arg1 = arg(1)')
 removed = shift()
